#!/bin/sh
# detect and install the needed nvidia driver package and configure intel iHD

case $1 in
	info)
		echo "Nvidia: $($0 detect_nvidia | head -n1)"
		echo "Intel: $($0 detect_intel)"
		;;
	detect_nvidia)
		while read package alias; do
			cat /sys/bus/pci/devices/*/modalias | grep -qi "^${alias//\*/.\*}$" && echo $package
		done < /usr/lib/xorg-driver-detect.aliases | uniq
		;;
	detect_intel)
		test "$(setting get display.forceDriver)" == "intel" && exit
		iHD_pci_ids="8086:56* 8086:4905 8086:46* 8086:4C* 8086:4E5* 8086:9B* 8086:71* 8086:9A* 8086:8A* 8086:9B* 8086:3E9* 8086:3EA* 8086:318* 8086:59* 8086:19*"
		pci_ids="$(sed -n "s/PCI_ID=//p" /sys/bus/pci/devices/*/uevent)"
		for pci_id in $iHD_pci_ids; do
			echo "$pci_ids" | grep -qi "^${pci_id//\*/.\*}$" && echo "iHD"
		done | uniq
		;;
	install)
		{
			package=$($0 detect_nvidia | head -n1)
			if [ "$package" ] && ! dpkg-query --show -f="\${db:Status-Abbrev}\${Package}\n" | grep -q "^ii $package$"; then
				export DEBIAN_FRONTEND=noninteractive
				apt-get -q update
				apt-get -q -y install $package
			fi
		} | while read line; do
			echo -e "$line\r"
			[ "$line" ] || continue
			[ "${line##Get*}" ] || ([ "${line##*Packages*}" -a "${line##*InRelease*}" ] && plymouth display-message --text="Downloading $(echo "$line" | cut -d " " -f4)" || plymouth display-message --text="Downloading updates")
			[ "${line##Unpacking*}" ] || plymouth display-message --text="$(echo "$line" | cut -d " " -f1-2)"
			[ "${line##Setting up*}" ] || plymouth display-message --text="$(echo "$line" | cut -d " " -f1-3)"
		done
		;;
	*)
		echo "Usage $0 {info | detect_nvidia | detect_intel | install}" >&2
		echo "  info             Show info about detected drivers" >&2
		echo "  detect_nvidia    Detect needed nvidia grafic driver package" >&2
		echo "  detect_intel     Detect intel iHD" >&2
		echo "  install          Install detected drivers" >&2
		exit 1
		;;
esac
